/* See LICENSE file for copyright and license details. */

/* appearance */
static const unsigned int borderpx  = 1;        /* border pixel of windows */
static const unsigned int snap      = 32;       /* snap pixel */
static const int showbar            = 1;        /* 0 means no bar */
static const int topbar             = 1;        /* 0 means bottom bar */
static const int focusonwheel       = 0;
static const char *fonts[]          = { "Liberation Sans:style=regular:size=11:antialias=true:autohint=true", "Font Awesome 5 Free:size=10:antialias=true:autohint=true" };
static const char dmenufont[]       = "Liberation Mono:size=11";
static const char col_gray1[]       = "#222222";
static const char col_gray2[]       = "#444444";
static const char col_gray3[]       = "#bbbbbb";
static const char col_gray4[]       = "#eeeeee";
static const char col_cyan[]        = "#005577";
static const char *colors[][3]      = {
	/*               fg         bg         border   */
	[SchemeNorm] = { col_gray3, col_gray1, col_gray2 },
	[SchemeSel]  = { col_gray4, col_cyan,  col_cyan  },
};

/* tagging */
static const char *tags[] = { "", "", "", "", "", "", "7", "8", "" };

static const Rule rules[] = {
	/* xprop(1):
	 *	WM_CLASS(STRING) = instance, class
	 *	WM_NAME(STRING) = title
	 */
	/* class      instance    title       tags mask     isfloating   monitor */
	{ "Gimp",     NULL,       NULL,       0,            1,           -1 },
	{ "Pale moon", "Navigator", NULL,     2,            0,           -1 },
	{ "Pale moon", "Browser", NULL,       2,            1,           -1 },
	{ "Pale moon", "Places",  NULL,       2,            1,           -1 },
	{ "Pale moon", "Toplevel", NULL,      2,            1,           -1 },
	{ "Pale moon", "Devtools", NULL,      2,            1,           -1 },
	{ "Pale moon", "DTA",     NULL,       2,            1,           -1 },
	{ "Pale moon", "Global",  NULL,       2,            1,           -1 },
	{ "Chromium-browser-chromium", "chromium-browser-chromium", NULL, 6, 0, -1 },
	{ "TelegramDesktop", "telegram-desktop", "Media viewer", 1 << 2, 1, -1 },
	{ "TelegramDesktop", "telegram-desktop", NULL, 1 << 2, 0,        -1 },
	{ "mpv",      NULL,       NULL,       1 << 3,       0,           -1 },
	{ "floatalsamxr", NULL,   NULL,       0,            1,           -1 },
	{ "QjackCtl", "qjackctl", NULL,       0,            1,           -1 },
	{ "Nextcloud", "nextcloud", NULL,       0,            1,           -1 },
};

#include "layouts.c"
/* layout(s) */
static const float mfact     = 0.55; /* factor of master area size [0.05..0.95] */
static const int nmaster     = 1;    /* number of clients in master area */
static const int resizehints = 1;    /* 1 means respect size hints in tiled resizals */
static const int lockfullscreen = 1; /* 1 will force focus on the fullscreen window */

static const Layout layouts[] = {
	/* symbol     arrange function */
	{ "[]=",      tile },    /* first entry is default */
	{ "><>",      NULL },    /* no layout function means floating behavior */
	{ "[M]",      monocle },
	{ "HHH",      grid },
};

/* key definitions */
#define MODKEY Mod4Mask
#define TAGKEYS(KEY,TAG) \
	{ MODKEY,                       KEY,      view,           {.ui = 1 << TAG} }, \
	{ MODKEY|ControlMask,           KEY,      toggleview,     {.ui = 1 << TAG} }, \
	{ MODKEY|ShiftMask,             KEY,      tag,            {.ui = 1 << TAG} }, \
	{ MODKEY|ControlMask|ShiftMask, KEY,      toggletag,      {.ui = 1 << TAG} },

/* helper for spawning shell commands in the pre dwm-5.0 fashion */
#define SHCMD(cmd) { .v = (const char*[]){ "/bin/sh", "-c", cmd, NULL } }

#include <X11/XF86keysym.h>

/* commands */
static char dmenumon[2] = "0"; /* component of dmenucmd, manipulated in spawn() */
static const char *dmenucmd[] = { "dmenu_run", "-m", dmenumon, "-fn", dmenufont, "-nb", col_gray1, "-nf", col_gray3, "-sb", col_cyan, "-sf", col_gray4, NULL };
static const char *termcmd[]  = { "st", NULL };
/* alsa volume control */
static const char *alsacmd[] = { "st", "-c", "floatalsamxr", "-e", "alsamixer", NULL };
static const char *upvol[] = { "amixer", "set", "Master", "2+", NULL };
static const char *downvol[] = { "amixer", "set", "Master", "2-", NULL };
/* alsa muting/unmuting */
static const char *mute[] = { "amixer", "-q", "set", "Master", "toggle", NULL };
/* screenshot tools */
static const char *scrallcmd[] = { "/home/kurk/sources/scripts/prtscr/prtscra.sh", NULL };
static const char *scrcurcmd[] = { "/home/kurk/sources/scripts/prtscr/prtscrcr.sh", NULL };
static const char *scrselcmd[] = { "/home/kurk/sources/scripts/prtscr/prtscrsel.sh", NULL };
/* browsers */
static const char *palemooncmd[]  = { "palemoon", NULL };
static const char *chromiumcmd[]  = { "chromium", NULL };
static const char *nextcloudcmd[]  = { "nextcloud", NULL };
static const char *xfecmd[]  = { "xfe", NULL };

static const Key keys[] = {
	/* modifier                     key        function        argument */
	{ MODKEY,                       XK_p,      spawn,          {.v = dmenucmd } },
	{ MODKEY|ShiftMask,             XK_Return, spawn,          {.v = termcmd } },
	{ 0,              XF86XK_AudioRaiseVolume, spawn,          {.v = upvol } },
	{ 0,              XF86XK_AudioLowerVolume, spawn,          {.v = downvol } },
	{ 0,              XF86XK_AudioMute,        spawn,          {.v = mute } },
	{ MODKEY,                       XK_Print,  spawn,          {.v = scrallcmd } },
	{ MODKEY|ShiftMask,             XK_Print,  spawn,          {.v = scrcurcmd } },
	{ MODKEY|ControlMask,           XK_Print,  spawn,          {.v = scrselcmd } },
	{ MODKEY,                       XK_s,      spawn,          {.v = palemooncmd } },
	{ MODKEY,                       XK_n,      spawn,          {.v = nextcloudcmd } },
	{ MODKEY,                       XK_c,      spawn,          {.v = chromiumcmd } },
	{ MODKEY|ShiftMask,             XK_x,      spawn,          {.v = xfecmd } },
	{ MODKEY,                       XK_b,      togglebar,      {0} },
	{ MODKEY,                       XK_j,      focusstack,     {.i = +1 } },
	{ MODKEY,                       XK_k,      focusstack,     {.i = -1 } },
	{ MODKEY,                       XK_i,      incnmaster,     {.i = +1 } },
	{ MODKEY,                       XK_d,      incnmaster,     {.i = -1 } },
	{ MODKEY,                       XK_h,      setmfact,       {.f = -0.05} },
	{ MODKEY,                       XK_l,      setmfact,       {.f = +0.05} },
	{ MODKEY,                       XK_Return, zoom,           {0} },
	{ MODKEY,                       XK_Tab,    view,           {0} },
	{ MODKEY|ShiftMask,             XK_c,      killclient,     {0} },
	{ MODKEY,                       XK_t,      setlayout,      {.v = &layouts[0]} },
	{ MODKEY,                       XK_f,      setlayout,      {.v = &layouts[1]} },
	{ MODKEY,                       XK_m,      setlayout,      {.v = &layouts[2]} },
	{ MODKEY,                       XK_g,      setlayout,      {.v = &layouts[3]} },
	{ MODKEY,                       XK_space,  setlayout,      {0} },
	{ MODKEY|ShiftMask,             XK_space,  togglefloating, {0} },
	{ MODKEY,                       XK_0,      view,           {.ui = ~0 } },
	{ MODKEY|ShiftMask,             XK_0,      tag,            {.ui = ~0 } },
	{ MODKEY,                       XK_comma,  focusmon,       {.i = -1 } },
	{ MODKEY,                       XK_period, focusmon,       {.i = +1 } },
	{ MODKEY|ShiftMask,             XK_comma,  tagmon,         {.i = -1 } },
	{ MODKEY|ShiftMask,             XK_period, tagmon,         {.i = +1 } },
	{ MODKEY|ControlMask,		  XK_l,	movekeyboard_x, 	{.i = 20}},
	{ MODKEY|ControlMask,		  XK_h,	movekeyboard_x, 	{.i = -20}},
	{ MODKEY|ControlMask,		  XK_j,	movekeyboard_y, 	{.i = 20}},
	{ MODKEY|ControlMask,		  XK_k,	movekeyboard_y, 	{.i = -20}},
	{ MODKEY,                       XK_Right,  viewnext,       {0} },
	{ MODKEY,                       XK_Left,   viewprev,       {0} },
	{ MODKEY|ShiftMask,             XK_Right,  tagtonext,      {0} },
	{ MODKEY|ShiftMask,             XK_Left,   tagtoprev,      {0} },
	TAGKEYS(                        XK_1,                      0)
	TAGKEYS(                        XK_2,                      1)
	TAGKEYS(                        XK_3,                      2)
	TAGKEYS(                        XK_4,                      3)
	TAGKEYS(                        XK_5,                      4)
	TAGKEYS(                        XK_6,                      5)
	TAGKEYS(                        XK_7,                      6)
	TAGKEYS(                        XK_8,                      7)
	TAGKEYS(                        XK_9,                      8)
	{ MODKEY|ShiftMask,             XK_q,      quit,           {0} },
};

/* button definitions */
/* click can be ClkTagBar, ClkLtSymbol, ClkStatusText, ClkWinTitle, ClkClientWin, or ClkRootWin */
static const Button buttons[] = {
	/* click                event mask      button          function        argument */
	{ ClkLtSymbol,          0,              Button1,        setlayout,      {0} },
	{ ClkLtSymbol,          0,              Button3,        setlayout,      {.v = &layouts[2]} },
	{ ClkWinTitle,          0,              Button2,        zoom,           {0} },
	{ ClkStatusText,        0,              Button2,        spawn,          {.v = termcmd } },
	{ ClkStatusText,        0,              Button1,        spawn,          {.v = alsacmd } },
	{ ClkClientWin,         MODKEY,         Button1,        movemouse,      {0} },
	{ ClkClientWin,         MODKEY,         Button2,        togglefloating, {0} },
	{ ClkClientWin,         MODKEY,         Button3,        resizemouse,    {0} },
	{ ClkTagBar,            0,              Button1,        view,           {0} },
	{ ClkTagBar,            0,              Button3,        toggleview,     {0} },
	{ ClkTagBar,            MODKEY,         Button1,        tag,            {0} },
	{ ClkTagBar,            MODKEY,         Button3,        toggletag,      {0} },
};

